@@ -6,7 +6,7 @@ use utf8;
 use Net::Whois::Raw;
 use Data::Dumper;
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 our @EXPORT = qw( parse_whois );
 
@@ -21,13 +21,15 @@ our %PARSERS = (
 our %FIELD_NAME_CONV = (
 
     # nameservers
-    nserver       => 'nameservers',
-    name_server   => 'nameservers',
-    name_serever  => 'nameservers',
-    name_server   => 'nameservers',
-    nameserver    => 'nameservers',
-    dns1          => 'nameservers',
-    dns2          => 'nameservers',
+    nserver          => 'nameservers',
+    name_server      => 'nameservers',
+    name_serever     => 'nameservers',
+    name_server      => 'nameservers',
+    nameserver       => 'nameservers',
+    dns1             => 'nameservers',
+    dns2             => 'nameservers',
+    primary_server   => 'nameservers',
+    secondary_server => 'nameservers',
 
     # domain
     domain_name   => 'domain',
@@ -38,6 +40,7 @@ our %FIELD_NAME_CONV = (
     created_on               => 'creation_date',
     creation_date            => 'creation_date',
     domain_registration_date => 'creation_date',
+    domain_created           => 'creation_date',
 
     #expiration_date
     expire                 => 'expiration_date',
@@ -105,7 +108,6 @@ sub parse_whois {
 
         my $whois = ref $args{raw} ? $args{raw} : [ { text => $args{raw}, srv => $server } ];
 
-
         return _process_parse($whois);
 
     }
@@ -151,6 +153,7 @@ sub _post_parse {
             # change keys to standard names
             my $new_key = lc $key;
             $new_key =~ s/\s+|\t+|-/_/g;
+            $new_key =~ s/\.+$//;
             if ( exists $FIELD_NAME_CONV{$new_key} ) {
                 $new_key =  $FIELD_NAME_CONV{$new_key};
             }
@@ -316,7 +319,7 @@ sub _default_parser {
         $line =~ s/^\s+//;
         $line =~ s/\s+$//;
 
-        my ( $key, $value ) = $line =~ /^\s*([\d\w\s_-]+):\s*(.+)$/;
+        my ( $key, $value ) = $line =~ /^\s*([\d\w\s._-]+):\s*(.+)$/;
         next if  !$line || !$value;
         $key =~ s/\s+$//;
         $value =~ s/\s+$//;
@@ -419,7 +422,7 @@ Net::Whois::Parser - module for parsing whois information
     $Net::Whois::Parser::FIELD_NAME_CONV{'Domain name'} = 'domain';
 
     # If you want to format some fields.
-    # I think it is very usefull for dates.
+    # I think it is very useful for dates.
     $Net::Whois::Parser::HOOKS{'expiration_date'} = [ \&format_date ];
 
 =head1 DESCRIPTION
